package
Version:
v0.0.0-...-6f327f8
Opens a new window with list of versions in this module.
Published: May 13, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func Discover(filterType string, filterAddr string, showAff, showTXT, showTD bool, waitSec int)
discover things and directories on the network
Source Files
¶
Click to show internal directories.
Click to hide internal directories.